@@ -1,12 +1,11 @@
 .onAttach <- function(libname, pkgname)
 {
-  ##set start-up message:
   txt <- c("\n",
-    paste(sQuote("garchx"), "version 1.0\n"),
+    paste(sQuote("garchx"), "version 1.1\n"),
     "\n",
-    paste0("Flexible and Robust GARCH-X Modelling"),
-#    "\n",
-#    paste("CRAN website: https://CRAN.R-project.org/package=garchx"),
+    paste0("Flexible and Robust GARCH-X modelling"),
+    "\n",
+    paste("CRAN website: https://CRAN.R-project.org/package=garchx"),
     "\n")
   
   ##print message:
