@@ -5,9 +5,7 @@ function(pars, aux)
   parsOK <- TRUE; sigma2OK <- TRUE
   
   ##check parameters:
-  if( any(is.na(pars))){
-    parsOK <- FALSE
-  }
+  if( any(is.na(pars))){ parsOK <- FALSE  }
 #  if( any(is.na(pars)) || any(pars<aux$lower) || any(pars>aux$upper) ){
 #    parsOK <- FALSE
 #  }
@@ -18,17 +16,17 @@ function(pars, aux)
   ##compute and check sigma2:
   if( parsOK ){
     sigma2 <- garchxRecursion(pars, aux)
-    if( any( sigma2 < 0 ) ){
+    sigma2 <- sigma2[ aux$maxpqrpluss1:aux$y.n ]
+    if( any(sigma2<=0) || any(sigma2==Inf) ){
       sigma2OK <- FALSE
     }else{
-      sigma2 <- #robustify log-transform in log-likelihood
-        pmax( aux$sigma2.min, sigma2 )
+      ##robustify log-transform in log-likelihood:
+      sigma2 <- pmax( aux$sigma2.min, sigma2 )
     }
   }
 
-  ##compute result:
+  ##compute average log-likelihood:
   if( parsOK && sigma2OK ){
-    sigma2 <- sigma2[ aux$maxpqrpluss1:aux$y.n ]
     if(aux$objective.fun==0){
       result <- mean( aux$ynotzero*(aux$y2short/sigma2 + log(sigma2)) )
     }
