@@ -4,6 +4,7 @@ function(x, ...){
   ##out1:
   pars <- coef.garchx(x)
   vcovmat <- vcov.garchx(x)
+  vcovComment <- comment(vcovmat)
   out1 <- rbind(pars, sqrt(diag(vcovmat)))
   rownames(out1) <- c("Estimate:", "Std. Error:")
 
@@ -16,13 +17,15 @@ function(x, ...){
   ##print message:
   cat("\n")
   cat("Date:", x$date, "\n")
-  cat("Method: Gaussian ML\n")
+#  cat("Dependent variable:", x$y.name, "\n")
+  cat("Method: normal ML\n")
+  cat("Coefficient covariance:", vcovComment, "\n")
   cat("Message (nlminb):", x$message, "\n")
   cat("No. of observations:", x$y.n - x$maxpqr, "\n")
   cat("Sample:", as.character(x$y.index[1]), "to", as.character(x$y.index[x$y.n]), 
       "\n")
   cat("\n")
-#  cat("Coefficients:\n")
+#  cat("Coefficients: \n ")
   print(out1)
   print(out2)
   cat("\n")
